@@ -1,8 +1,8 @@
 #define DTK_VERSION_MAJOR 2
 #define DTK_VERSION_MINOR 0
-#define DTK_VERSION_PATCH 9
-#define DTK_VERSION_BUILD 17
-#define DTK_VERSION_STR "2.0.9.17"
+#define DTK_VERSION_PATCH 10
+#define DTK_VERSION_BUILD 0
+#define DTK_VERSION_STR "2.0.10"
 //
 #define DTKCORE_CLASS_DObject
 #define DTKCORE_CLASS_DObjectPrivate
@@ -11,6 +11,7 @@
 #define DTKCORE_CLASS_DPinyin
 #define DTKCORE_CLASS_DDBusSender
 #define DTKCORE_CLASS_DRecentManager
+#define DTKCORE_CLASS_DNotifySender
 #define DTKCORE_CLASS_DLog
 #define DTKCORE_CLASS_DFileWatcher
 #define DTKCORE_CLASS_DBaseFileWatcher
